@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+import re
 from functools import lru_cache
-from re import findall
+
+to_camel_pattern = re.compile(r"([a-zA-Z][^A-Z0-9]*|[0-9]+)")
 
 
 @lru_cache(maxsize=256)
@@ -29,7 +31,7 @@ def to_snake(camel_string: str) -> str:
     Returns:
         The string in snake case format. For example my_variable.
     """
-    words = findall("([a-zA-Z][^A-Z0-9]*|[0-9]+)", camel_string)
+    words = to_camel_pattern.findall(camel_string)
 
     return "_".join(word.lower() for word in words)
 
